@@ -1,7 +1,22 @@
 # coding: utf-8
-
-from subprocess import check_output
 import re
+try:
+    from subprocess import check_output
+except ImportError:
+    import subprocess
+
+    def check_output(*popenargs, **kwargs):
+        process = subprocess.Popen(stdout=subprocess.PIPE, *popenargs, **kwargs)
+        output, unused_err = process.communicate()
+        retcode = process.poll()
+        if retcode:
+            cmd = kwargs.get("args")
+            if cmd is None:
+                cmd = popenargs[0]
+            error = subprocess.CalledProcessError(retcode, cmd)
+            error.output = output
+            raise error
+        return output
 
 
 class RepositoryIntrospector:
@@ -40,4 +55,4 @@ class RepositoryIntrospector:
         elif host == "bitbucket.org":
             return "b"
 
-        raise Exception("Unknown host " + host)
\ No newline at end of file
+        raise Exception("Unknown host " + host)
